@@ -2,15 +2,15 @@
 //!
 //!## Available data structures
 //!
-//!- [RingBuffer](ring_buffer/index.html)
-//!- [Vec](vec/index.html)
+//!- [Array](struct.Array.html)
 //!
 //!## Crate features
 //!
-//!- `std` Enables some std interfaces (e.g. `Write`) implementations.
+//!- `std` - Enables some std interfaces (e.g. `Write`) implementations.
+//!- `serde` - Enables serialization/deserialization implementations.
 
 #![no_std]
-//#![deny(warnings)]
+#![deny(warnings)]
 #![warn(missing_docs)]
 #![cfg_attr(feature = "cargo-clippy", allow(clippy::style))]
 
@@ -19,3 +19,6 @@ extern crate std;
 
 mod vec;
 pub use vec::Array;
+
+#[cfg(feature = "serde")]
+mod serde;
